import { toDate } from "./toDate.mjs";
import { constructFrom } from "./constructFrom.mjs";
import { getMonth as coreGetMonth } from "./_core/getMonth.mjs";
import { getDate as coreGetDate } from "./_core/getDate.mjs";
import { getFullYear as coreGetFullYear } from "./_core/getFullYear.mjs";
import { setFullYear as coreSetFullYear } from "./_core/setFullYear.mjs";

/**
 * @name getDaysInMonth
 * @category Month Helpers
 * @summary Get the number of days in a month of the given date.
 *
 * @description
 * Get the number of days in a month of the given date.
 *
 * @typeParam DateType - The `Date` type, the function operates on. Gets inferred from passed arguments. Allows to use extensions like [`UTCDate`](https://github.com/date-fns/utc).
 *
 * @param date - The given date
 *
 * @returns The number of days in a month
 *
 * @example
 * // How many days are in February 2000?
 * const result = getDaysInMonth(new Date(2000, 1))
 * //=> 29
 */
export function getDaysInMonth(date) {
  const _date = toDate(date);
  const year = coreGetFullYear(_date);
  const monthIndex = coreGetMonth(_date);
  const lastDayOfMonth = constructFrom(date, 0);
  coreSetFullYear(lastDayOfMonth, year, monthIndex + 1, 0);
  lastDayOfMonth.setHours(0, 0, 0, 0);
  return coreGetDate(lastDayOfMonth);
}

// Fallback for modularized imports:
export default getDaysInMonth;
